import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:puma_ui/ui/molecules/pumaCupertinoButton.dart';
import 'package:puma_ui/ui/molecules/pumaMaterialButton.dart';

showPumaAlert(
  BuildContext context, {
  String title = "",
  String message = "",
  String yes = "OK",
  String? no,
  void Function()? onYes,
  void Function()? onNo,
  Color yesColor = Colors.red,
  Color noColor = Colors.blue,
  bool delayYesAction = false,
  int delayActionSecond = 5,
}) {
  var alert;

  if (Platform.isIOS) {
    alert = CupertinoAlertDialog(
      title: new Text(title),
      content: new Text(message),
      actions: [
        if (no != null)
          PumaCupertinoButton(
            text: no,
            color: noColor,
            onPressed: onNo == null ? () => Navigator.of(context).pop() : onNo,
          ),
        PumaCupertinoButton(
          text: yes,
          color: yesColor,
          onPressed: onYes!,
          delayAction: delayYesAction ? delayActionSecond : 0,
        )
      ],
    );
  } else {
    alert = AlertDialog(
      title: Text(title),
      content: Text(message),
      actions: [
        if (no != null)
          PumaMaterialButton(
            text: no,
            color: noColor,
            onPressed: onNo == null ? () => Navigator.of(context).pop() : onNo,
          ),
        PumaMaterialButton(
          text: yes,
          color: yesColor,
          onPressed: onYes!,
          delayAction: delayYesAction ? delayActionSecond : 0,
        ),
      ],
    );
  }

  showDialog(
    context: context,
    builder: (BuildContext context) {
      return alert;
    },
  );
}
