import 'package:flutter/material.dart';

class PumaButton extends StatelessWidget {
  final String title;
  final String? subtitle;
  final Color color;
  final Color textcolor;
  final bool disabled;
  final Icon? icon;
  final double titleFontSize;
  final double? width;
  final void Function() onPressed;

  PumaButton({
    Key? key,
    this.title = "",
    this.subtitle,
    this.color = Colors.white,
    this.textcolor = Colors.black,
    this.disabled = false,
    this.icon,
    this.titleFontSize = 18,
    this.width,
    required this.onPressed,
  }) : super(key: key);

  Widget getIcon() {
    return Padding(
      padding: const EdgeInsets.only(
        right: 4.0,
      ),
      child: icon!,
    );
  }

  Widget build(BuildContext context) {
    return Opacity(
      opacity: disabled ? 0.5 : 1,
      child: ElevatedButton(
        child: Container(
          width: this.width,
          child: FittedBox(
            fit: BoxFit.scaleDown,
            alignment: Alignment.topCenter,
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                if (icon != null) getIcon(),
                Text(
                  title,
                  style: TextStyle(
                      fontFamily: "Futura-Bold",
                      fontSize: titleFontSize,
                      color: textcolor),
                ),
                if (subtitle != null)
                  Opacity(
                    opacity: 0.58,
                    child: Text(
                      subtitle!,
                      style: TextStyle(
                          fontFamily: "Futura-Bold",
                          fontSize: 12,
                          color: textcolor),
                    ),
                  ),
              ],
            ),
          ),
        ),
        style: ButtonStyle(
          backgroundColor: MaterialStateProperty.all(color),
        ),
        onPressed: disabled ? null : onPressed,
      ),
    );
  }
}
