import 'dart:async';

import 'package:flutter/material.dart';

class PumaMaterialButton extends StatefulWidget {
  final String text;
  final Color color;
  final void Function() onPressed;
  final int delayAction;

  const PumaMaterialButton({
    Key? key,
    required this.text,
    required this.color,
    required this.onPressed,
    this.delayAction = 0,
  }) : super(key: key);

  @override
  _PumaMaterialButtonState createState() => _PumaMaterialButtonState();
}

class _PumaMaterialButtonState extends State<PumaMaterialButton> {
  String text = "";
  Color color = Colors.black;
  int delayAction = 0;

  @override
  void initState() {
    super.initState();

    setState(() {
      if (widget.delayAction > 0) {
        text = "${widget.text} (${widget.delayAction})";
      } else {
        text = widget.text;
      }
      color = widget.color;
      delayAction = widget.delayAction;
    });
    if (widget.delayAction > 0) {
      startTimer();
    }
  }

  Timer startTimer() {
    const oneSec = const Duration(seconds: 1);
    return new Timer.periodic(
      oneSec,
      (Timer timer) {
        if (mounted) {
          if (delayAction == 1) {
            timer.cancel();
            setState(() {
              text = widget.text;
              delayAction = 0;
            });
          } else {
            setState(() {
              delayAction--;
              text = "${widget.text} ($delayAction)";
            });
          }
        } else {
          timer.cancel();
        }
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return TextButton(
      child: Opacity(
        opacity: delayAction > 0 ? 0.6 : 1,
        child: Text(
          text,
          style: TextStyle(color: color),
        ),
      ),
      onPressed: delayAction > 0 ? null : widget.onPressed,
    );
  }
}
